%BIOMED 194 objects with 5 features in 2 classes
%
%       X = BIOMED;
%
% The biomed dataset to develop screening methods to identify carriers
% of a rare genetic disorder.  Because the disease is rare, there are
% only a few carriers of the disease from whom data are available.
%
%       X = BIOMED(VAL)
%
% By default objects with missing values are removed. When something else
% is desired, use one of the options in MISVAL for VAL.
%
% This is the ''biomed' dataset of the <a href="http://lib.stat.cmu.edu/datasets/">StatLib Datasets Archive</a>.
% Just the original features 3, 5, 6, 7 and 8 are used.
%
% SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
% PRTOOLS, DATASETS, MISVAL

% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com

function a = biomed(val)

if nargin < 1, val = 'remove'; end

a = pr_loadmatfile;
if isempty(a)
  opt.labfeat   = 9;
  opt.feats     = [3,5,6,7,8];
  opt.featnames = {'age' 'measurement 1' 'measurement 2' 'measurement 3' 'measurement 4'};
  opt.classnames = {'carrier' 'normal'};
  opt.desc = 'The purpose of the analysis is to develop a screening procedure to detect carriers and to describe its effectiveness. ';
  opt.link = 'http://lib.stat.cmu.edu/datasets/';
  opt.dsetname = 'Biomedical Data';
  a = pr_download('http://prtools.tudelft.nl/prdatasets/biomed.dat',[],opt);
end
a = misval(a,val);

return
